# iThera Medical Python 3 Environment

* This module will install base libraries for iThera Medical tools.
* No iThera tools will be installed upon iTheraPY installation. iThera tools must be installed separately after installing iTheraPY.
* When installing specific iThera tools, it might be required to install additional libraries/binary distributions (wheels). Please refer to the tool-specific installation guide. 
